@@ -2,16 +2,15 @@ from . import asynconnect
 from rs4 import webtest
 import threading
 import time
+from .baseconnect import BaseConnect
 
-class SynConnect (asynconnect.AsynConnect):
+class SynConnect (asynconnect.AsynConnect, BaseConnect):
     ssl = False
     proxy = False
 
     def __init__ (self, address, lock = None, logger = None):
+        BaseConnect.__init__ (self, lock, logger)
         self.address = address
-        self.lock = lock
-        self.logger = logger
-        self._cv = threading.Condition ()
         self.auth = None
         self.set_event_time ()
         self.initialize_connection ()
@@ -42,3 +41,4 @@ class SynConnect (asynconnect.AsynConnect):
 
 class SynSSLConnect (SynConnect):
     ssl = True
+
