@@ -170,7 +170,7 @@ class AsynConnect (asynredis._AsynConnect):
                     return self.kill_cursors ([cursor_id])
 
         self.has_result = True
-        self.close_case_with_end_tran ()
+        self.end_tran ()
 
     def fetchall (self):
         r = self.response
