@@ -27,34 +27,27 @@ class AsynConnect (dbconnect.AsynDBConnect, asyncore.dispatcher):
 		self.execute (request)
 		return _STATE_RETRY
 
-	def check_state (self, state):
-		if state == _STATE_RETRY:
-			return
-		if state not in (_STATE_OK):
-			self.logger ("[warn] psycopg2.poll() returned %s" % state)
-			self.handle_close ()
-
 	def poll (self):
 		# 2 cases, if on requesting raise immediatly, else handle silently
 		try:
-			if REREY_TEST and self.writable () and self.request.retry_count == 0:
-				#raise psycopg2.InterfaceError
-				self.disconnect ()
-			return self.socket.poll ()
-		except (psycopg2.OperationalError, psycopg2.InterfaceError):
-			if self.request:
-				if self.request.retry_count == 0:
-					self.request.retry_count += 1
-					return self.retry ()
-				else:
-					raise
-			self.logger.trace ()
-		except:
-			# else usually timeout
-			if self.request:
+			try:
+				if REREY_TEST and self.writable () and self.request.retry_count == 0:
+					self.disconnect ()
+				state = self.socket.poll ()
+				if state not in _STATE_OK:
+					self.logger ("[warn] psycopg2.poll() returned %s" % state)
+					return self.handle_expt ()
+				return state
+
+			except (psycopg2.OperationalError, psycopg2.InterfaceError):
+				if self.request:
+					if self.request.retry_count == 0:
+						self.request.retry_count += 1
+						return self.retry ()
 				raise
-			self.logger.trace ()
-		return _STATE_IGNORE
+
+		except:
+			self.handle_error ()
 
 	def writable (self):
 		return self.out_buffer or not self.connected
@@ -77,8 +70,6 @@ class AsynConnect (dbconnect.AsynDBConnect, asyncore.dispatcher):
 			self.handle_connect ()
 			self.connected = True
 			self.connecting = False
-		else:
-			self.check_state (state)
 
 	def handle_write_event (self):
 		if not self.connected:
@@ -97,9 +88,7 @@ class AsynConnect (dbconnect.AsynDBConnect, asyncore.dispatcher):
 		if self.cur and state == POLL_OK:
 			self.set_event_time ()
 			self.has_result = True
-			self.close_case_with_end_tran ()
-		else:
-			self.check_state (state)
+			self.end_tran ()
 
 	def handle_write (self):
 		state = self.poll ()
@@ -109,8 +98,6 @@ class AsynConnect (dbconnect.AsynDBConnect, asyncore.dispatcher):
 			self.set_event_time ()
 			self.cur.execute (self.out_buffer)
 			self.out_buffer = ""
-		else:
-			self.check_state (state)
 
 	#-----------------------------------
 	# Overriden
@@ -130,7 +117,7 @@ class AsynConnect (dbconnect.AsynDBConnect, asyncore.dispatcher):
 				self.logger.trace ()
 			self.cur = None
 
-	def close_case (self):
+	def end_tran (self):
 		if self.request:
 			description, data = self.cur and self.cur.description or None, None
 			if description:
@@ -143,7 +130,7 @@ class AsynConnect (dbconnect.AsynDBConnect, asyncore.dispatcher):
 			self.request.handle_result (description or None, self.expt, data)
 			self.request = None
 		self.close_cursor ()
-		self.set_active (False)
+		dbconnect.AsynDBConnect.end_tran (self)
 
 	def fetchall (self):
 		data = self.cur.fetchall ()
@@ -169,9 +156,6 @@ class AsynConnect (dbconnect.AsynDBConnect, asyncore.dispatcher):
 		)
 		self.set_socket (sock)
 
-	def end_tran (self):
-		pass
-
 	def _compile (self, request):
 		sql = request.params [0]
 		if isinstance (sql, (list, tuple)):
