@@ -113,7 +113,7 @@ def maintern_zombie_channel (now, map = None):
 	if map is None:
 		map = asyncore.socket_map
 
-	for channel in list(map.values()):
+	for channel in map.values():
 		if hasattr (channel, "handle_timeout"):
 			try:
 				# +3 is make gap between server & client
@@ -202,7 +202,7 @@ def remove_notsocks (map):
 	# on Windows we can get WSAENOTSOCK if the client
 	# rapidly connect and disconnects
 	killed = 0
-	for fd, obj in list(map.items()):
+	for fd, obj in map.items():
 		r = []; w = []; e = []
 		is_r = obj.readable()
 		is_w = obj.writable()
@@ -252,7 +252,10 @@ def poll_fun_wrap (timeout, map = None):
 
 	except (TypeError, OSError) as why:
 		_logger and _logger.trace ()
-		remove_notsocks (map) # WSAENOTSOCK
+		killed = remove_notsocks (map) # WSAENOTSOCK
+		if not killed:
+			# no errors, restart worker
+			raise
 
 	except ValueError:
 		_logger and _logger.trace ()
@@ -262,7 +265,7 @@ def poll_fun_wrap (timeout, map = None):
 			half = int (len (map) / 2)
 			tmap = {}
 			cc = 0
-			for k, v in list(map.items ()):
+			for k, v in map.items ():
 				tmap [k] = v
 				cc += 1
 				if cc == half:
@@ -304,7 +307,7 @@ def graceful_shutdown_loop ():
 	while map and _shutdown_phase < 4:
 		time_in_this_phase = time.time() - timestamp
 		veto = 0
-		for fd,obj in list(map.items()):
+		for fd,obj in map.items():
 			try:
 				fn = getattr (obj,'clean_shutdown_control')
 			except AttributeError:
