@@ -187,7 +187,8 @@ class Stream(object):
         # Append the data to the buffer.
         self.data.append(event.data)
 
-        if increment:
+        # ignore if stream_ended: edited by Hans Roh 2020. 5.12
+        if not event.stream_ended and increment:
             try:
                 with self._conn as conn:
                     conn.increment_flow_control_window(
